@@ -15,20 +15,22 @@
 #'                                !is.na(Total) & Total != 0)
 #' 
 #' par <- c(S.low=0.5, S.high=0.3, 
-#'          P.low=25, deltaP=10, MaxHS=logit(0.8))
+#'          P.low=25, deltaP=10, MaxHS=0.8)
 #'          
-#' HatchingSuccesss.lnL(par=par, data=totalIncubation_Cc)
+#' HatchingSuccess.lnL(par=par, data=totalIncubation_Cc)
 #' 
-#' g <- HatchingSuccesss.fit(par=par, data=totalIncubation_Cc)
+#' g <- HatchingSuccess.fit(par=par, data=totalIncubation_Cc)
 #' 
-#' HatchingSuccesss.lnL(par=g$par, data=totalIncubation_Cc)
+#' HatchingSuccess.lnL(par=g$par, data=totalIncubation_Cc)
 #' 
 #' plot(g)
+#' 
+#' nobs(g)
 #' }
 #' @method nobs HatchingSuccess
 #' @export
 
 nobs.HatchingSuccess <- function(object, ...) {
-  return(nrow(object$data))
+  return(sum(object$data[, object$column.Hatched] + object$data[, object$column.NotHatched]))
 }
 
